pm4py.algo.organizational\_mining.network\_analysis.variants package
====================================================================

Submodules
----------

pm4py.algo.organizational\_mining.network\_analysis.variants.dataframe module
-----------------------------------------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.network_analysis.variants.dataframe
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.organizational_mining.network_analysis.variants
   :members:
   :undoc-members:
   :show-inheritance:
